---
name: Question or Problem
about: Ask a question or ask about a problem
title: ""
labels: question
assignees: ""

---

### First check

* [ ] I added a very descriptive title to this issue.
* [ ] I used the GitHub search to find a similar issue and didn't find it.
* [ ] I searched the ticts documentation, with the integrated search.
* [ ] I already searched in Google "How to X in ticts" and didn't find any information.
* [ ] I already read and followed all the tutorial in the docs and didn't find an answer.
    * Read open issues with questions until I find 2 issues where I can help someone and add a comment to help there.
    * I already hit the "watch" button in this repository to receive notifications and I commit to help at least 2 people that ask questions in the future.
    * Implement a Pull Request for a confirmed bug.

### Example

Here's a self-contained [minimal, reproducible, example](https://stackoverflow.com/help/minimal-reproducible-example) with my use case:

<!-- Replace the code below with your own self-contained, minimal, reproducible, example -->

```python
import ticts

...
```
